@@ -47,6 +47,7 @@ public:
   
   Chunk::data_type    data();
 
+  bool                next();
   bool                used(uint32_t length);
 
 private:
@@ -74,6 +75,13 @@ ChunkIterator::data() {
   return data;
 }
 
+inline bool
+ChunkIterator::next() {
+  m_first = m_iterator->position() + m_iterator->size();
+
+  return m_first < m_last && ++m_iterator != m_chunk->end();
+}
+
 inline bool
 ChunkIterator::used(uint32_t length) {
   m_first += length;
