@@ -46,28 +46,43 @@
 
 namespace torrent {
 
+class ChunkManager;
 class Content;
+class DownloadWrapper;
+class EntryList;
 
 class ChunkList : private std::vector<ChunkListNode> {
 public:
-  typedef uint32_t                                      size_type;
-  typedef std::pair<Chunk*,rak::error_number>           CreateChunk;
-  typedef std::vector<ChunkListNode>                    Base;
-  typedef std::vector<ChunkListNode*>                   Queue;
-  typedef rak::mem_fun2<Content, CreateChunk, uint32_t, bool> SlotCreateChunk;
+  typedef uint32_t                            size_type;
+  typedef std::vector<ChunkListNode>          base_type;
+  typedef std::pair<Chunk*,rak::error_number> CreateChunk;
+  typedef std::vector<ChunkListNode*>         Queue;
 
-  using Base::value_type;
-  using Base::reference;
-  using Base::difference_type;
+  typedef rak::mem_fun2<Content, CreateChunk, uint32_t, bool>      SlotCreateChunk;
+  typedef rak::const_mem_fun0<EntryList, uint64_t>                 SlotFreeDiskspace;
+  typedef rak::mem_fun1<DownloadWrapper, void, const std::string&> SlotStorageError;
 
-  using Base::iterator;
-  using Base::reverse_iterator;
-  using Base::size;
-  using Base::empty;
+  using base_type::value_type;
+  using base_type::reference;
+  using base_type::difference_type;
 
-  ChunkList() : m_maxQueueSize(~uint32_t()), m_timeoutSync(300), m_timeoutSafeSync(600) {}
+  using base_type::iterator;
+  using base_type::reverse_iterator;
+  using base_type::size;
+  using base_type::empty;
+
+  static const int sync_all          = (1 << 0);
+  static const int sync_force        = (1 << 1);
+  static const int sync_safe         = (1 << 2);
+  static const int sync_sloppy       = (1 << 3);
+  static const int sync_use_timeout  = (1 << 4);
+  static const int sync_ignore_error = (1 << 5);
+
+  ChunkList() : m_manager(NULL) {}
   ~ChunkList() { clear(); }
 
+  void                set_manager(ChunkManager* manager)      { m_manager = manager; }
+
   bool                has_chunk(size_type index, int prot) const;
 
   void                resize(size_type s);
@@ -76,38 +91,38 @@ public:
   ChunkHandle         get(size_type index, bool writable);
   void                release(ChunkHandle* handle);
 
-  uint32_t            max_queue_size() const                  { return m_maxQueueSize; }
-  void                set_max_queue_size(uint32_t v)          { m_maxQueueSize = v; }
+  size_type           queue_size() const                      { return m_queue.size(); }
 
-  uint32_t            timeout_sync() const                    { return m_timeoutSync; }
-  void                set_timeout_sync(uint32_t seconds)      { m_timeoutSync = seconds; }
+  // Replace use_timeout with something like performance related
+  // keyword. Then use that flag to decide if we should skip
+  // non-continious regions.
 
-  uint32_t            timeout_safe_sync() const               { return m_timeoutSafeSync; }
-  void                set_timeout_safe_sync(uint32_t seconds) { m_timeoutSafeSync = seconds; }
-
-  // Possibly have multiple version, some that do syncing of
-  // sequential chunks only etc. Pretty much depends on the time of
-  // dereferencing etc.
-  //
   // Returns the number of failed syncs.
-  unsigned int        sync_all(int flags);
-  unsigned int        sync_periodic();
+  uint32_t            sync_chunks(int flags);
 
-  void                slot_create_chunk(SlotCreateChunk s) { m_slotCreateChunk = s; }
+  void                slot_storage_error(SlotStorageError s)   { m_slotStorageError = s; }
+  void                slot_create_chunk(SlotCreateChunk s)     { m_slotCreateChunk = s; }
+  void                slot_free_diskspace(SlotFreeDiskspace s) { m_slotFreeDiskspace = s; }
 
 private:
   inline bool         is_queued(ChunkListNode* node);
 
-  static inline bool  sync_chunk(ChunkListNode* node, int flags, bool cleanup);
+  inline void         clear_chunk(ChunkListNode* node);
+  inline bool         sync_chunk(ChunkListNode* node, std::pair<int,bool> options);
 
+  Queue::iterator     partition_optimize(Queue::iterator first, Queue::iterator last, int weight, int maxDistance, bool dontSkip);
+
+  inline Queue::iterator seek_range(Queue::iterator first, Queue::iterator last);
+  inline bool            check_node(ChunkListNode* node);
+
+  std::pair<int,bool> sync_options(ChunkListNode* node, int flags);
+
+  ChunkManager*       m_manager;
   Queue               m_queue;
 
-  uint32_t            m_maxQueueSize;
-
-  uint32_t            m_timeoutSync;
-  uint32_t            m_timeoutSafeSync;
-
+  SlotStorageError    m_slotStorageError;
   SlotCreateChunk     m_slotCreateChunk;
+  SlotFreeDiskspace   m_slotFreeDiskspace;
 };
 
 }
