@@ -38,15 +38,17 @@
 
 #include <algorithm>
 #include <functional>
+#include <limits>
 #include <memory>
 #include <rak/error_number.h>
+#include <rak/file_stat.h>
+#include <rak/fs_stat.h>
 #include <rak/functional.h>
 
 #include "torrent/exceptions.h"
 #include "torrent/path.h"
 
 #include "chunk.h"
-#include "directory.h"
 #include "file_meta.h"
 #include "entry_list.h"
 #include "memory_chunk.h"
@@ -89,30 +91,33 @@ EntryList::open() {
   if (m_rootDir.empty())
     throw internal_error("EntryList::open() m_rootDir.empty().");
 
+  m_indirectLinks.push_back(m_rootDir);
+
   Path lastPath;
   iterator itr = begin();
 
   try {
-    make_directory(m_rootDir);
+    if (::mkdir(m_rootDir.c_str(), 0777) && errno != EEXIST)
+      throw storage_error("Could not create directory '" + m_rootDir + "': " + strerror(errno));
+  
+    while (itr != end()) {
+      EntryListNode* entry = *itr++;
 
-    for (iterator last = end(); itr != last; ++itr) {
-      if ((*itr)->file_meta()->is_open())
+      if (entry->file_meta()->is_open())
         throw internal_error("EntryList::open(...) found an already opened file.");
       
-      m_slotInsertFileMeta((*itr)->file_meta());
+      m_slotInsertFileMeta(entry->file_meta());
 
-      if ((*itr)->path()->empty())
+      if (entry->path()->empty())
         throw storage_error("Found an empty filename.");
 
-      if (!open_file(&*(*itr), lastPath))
-        throw storage_error("Could not open file \"" + m_rootDir + (*itr)->path()->as_string() + "\": " + rak::error_number::current().c_str());
+      if (!open_file(&*entry, lastPath))
+        throw storage_error("Could not open file \"" + m_rootDir + entry->path()->as_string() + "\": " + rak::error_number::current().c_str());
       
-      lastPath = *(*itr)->path();
+      lastPath = *entry->path();
     }
 
   } catch (storage_error& e) {
-    itr++;
-
     for (iterator cleanupItr = begin(); cleanupItr != itr; ++cleanupItr)
       m_slotEraseFileMeta((*cleanupItr)->file_meta());
 
@@ -134,11 +139,17 @@ EntryList::close() {
   }
 
   m_isOpen = false;
+  m_indirectLinks.clear();
 }
 
 void
 EntryList::set_root_dir(const std::string& path) {
-  m_rootDir = path;
+  std::string::size_type last = path.find_last_not_of('/');
+
+  if (last == std::string::npos)
+    m_rootDir = ".";
+  else
+    m_rootDir = path.substr(0, last + 1);
 
   for (iterator itr = begin(), last = end(); itr != last; ++itr) {
     if ((*itr)->file_meta()->is_open())
@@ -171,13 +182,51 @@ EntryList::at_position(iterator itr, off_t offset) {
   return itr;
 }
 
+inline void
+EntryList::make_directory(Path::const_iterator pathBegin, Path::const_iterator pathEnd, Path::const_iterator startItr) {
+  std::string path = m_rootDir;
+
+  while (pathBegin != pathEnd) {
+    path += "/" + *pathBegin;
+
+    if (pathBegin++ != startItr)
+      continue;
+
+    startItr++;
+
+    rak::file_stat fileStat;
+
+    if (fileStat.update_link(path) &&
+        fileStat.is_link() &&
+        std::find(m_indirectLinks.begin(), m_indirectLinks.end(), path) == m_indirectLinks.end())
+      m_indirectLinks.push_back(path);
+
+    if (pathBegin == pathEnd)
+      break;
+
+    if (::mkdir(path.c_str(), 0777) && errno != EEXIST)
+      throw storage_error("Could not create directory '" + path + "': " + strerror(errno));
+  }
+}
+
 bool
 EntryList::open_file(EntryListNode* node, const Path& lastPath) {
-  make_directory(m_rootDir, node->path()->begin(), --node->path()->end(), lastPath.begin(), lastPath.end());
+  const Path* path = node->path();
+
+  Path::const_iterator lastItr = lastPath.begin();
+  Path::const_iterator firstMismatch = path->begin();
+
+  // Couldn't find a suitable stl algo, need to write my own.
+  while (firstMismatch != path->end() && lastItr != lastPath.end() && *firstMismatch == *lastItr) {
+    lastItr++;
+    firstMismatch++;
+  }
+
+  make_directory(path->begin(), path->end(), firstMismatch);
 
   // Some torrents indicate an empty directory by having a path with
   // an empty last element. This entry must be zero length.
-  if (node->path()->back().empty())
+  if (path->back().empty())
     return node->size() == 0;
 
   return
@@ -185,22 +234,38 @@ EntryList::open_file(EntryListNode* node, const Path& lastPath) {
     node->file_meta()->prepare(MemoryChunk::prot_read, SocketFile::o_create);
 }
 
+// This function should really ensure that we arn't dealing files
+// spread over multiple mount-points.
+uint64_t
+EntryList::free_diskspace() const {
+  uint64_t freeDiskspace = std::numeric_limits<uint64_t>::max();
+
+  for (path_list::const_iterator itr = m_indirectLinks.begin(), last = m_indirectLinks.end(); itr != last; ++itr) {
+    rak::fs_stat stat;
+
+    if (!stat.update(*itr))
+      continue;
+
+    freeDiskspace = std::min<uint64_t>(freeDiskspace, stat.bytes_avail());
+  }
+
+  return freeDiskspace != std::numeric_limits<uint64_t>::max() ? freeDiskspace : 0;
+}
+
 inline MemoryChunk
 EntryList::create_chunk_part(iterator itr, off_t offset, uint32_t length, int prot) {
-  MemoryChunk chunk;
-
   offset -= (*itr)->position();
   length = std::min<off_t>(length, (*itr)->size() - offset);
 
   if (offset < 0)
     throw internal_error("EntryList::chunk_part(...) caught a negative offset");
 
-  if ((*itr)->file_meta()->prepare(prot))
-    chunk = (*itr)->file_meta()->get_file().create_chunk(offset, length, prot, MemoryChunk::map_shared);
-  else
-    chunk.clear();
+  // Check that offset != length of file.
 
-  return chunk;
+  if (!(*itr)->file_meta()->prepare(prot))
+    return MemoryChunk();
+
+  return (*itr)->file_meta()->get_file().create_chunk(offset, length, prot, MemoryChunk::map_shared);
 }
 
 Chunk*
@@ -223,13 +288,22 @@ EntryList::create_chunk(off_t offset, uint32_t length, int prot) {
     if (!mc.is_valid())
       return NULL;
 
+    if (mc.size() == 0)
+      throw internal_error("EntryList::create_chunk(...) mc.size() == 0.");
+
+    if (mc.size() > length)
+      throw internal_error("EntryList::create_chunk(...) mc.size() > length.");
+
     chunk->push_back(ChunkPart::MAPPED_MMAP, mc);
 
     offset += mc.size();
     length -= mc.size();
   }
 
-  return !chunk->empty() ? chunk.release() : NULL;
+  if (chunk->empty())
+    return NULL;
+
+  return chunk.release();
 }
 
 }
