@@ -52,6 +52,7 @@ class MemoryChunk;
 class EntryList : private std::vector<EntryListNode*> {
 public:
   typedef std::vector<EntryListNode*>                 base_type;
+  typedef std::vector<std::string>                    path_list;
   typedef rak::mem_fun1<FileManager, void, FileMeta*> slot_meta_type;
 
   using base_type::value_type;
@@ -91,18 +92,26 @@ public:
   size_t              files_size() const                         { return base_type::size(); }
   off_t               bytes_size() const                         { return m_bytesSize; }
 
+  // If the files span multiple disks, the one with the least amount
+  // of free diskspace will be returned.
+  uint64_t            free_diskspace() const;
+
   EntryListNode*      get_node(uint32_t idx)                     { return base_type::operator[](idx); }
 
   Chunk*              create_chunk(off_t offset, uint32_t length, int prot);
 
   iterator            at_position(iterator itr, off_t offset);
 
+  path_list*          indirect_links()                           { return &m_indirectLinks; }
+
   void                slot_insert_filemeta(slot_meta_type s)     { m_slotInsertFileMeta = s; }
   void                slot_erase_filemeta(slot_meta_type s)      { m_slotEraseFileMeta = s; }
 
 private:
   bool                open_file(EntryListNode* node, const Path& lastPath);
 
+  inline void         make_directory(Path::const_iterator pathBegin, Path::const_iterator pathEnd, Path::const_iterator startItr);
+
   inline MemoryChunk  create_chunk_part(iterator itr, off_t offset, uint32_t length, int prot);
 
   off_t               m_bytesSize;
@@ -110,6 +119,8 @@ private:
 
   bool                m_isOpen;
 
+  path_list           m_indirectLinks;
+
   slot_meta_type      m_slotInsertFileMeta;
   slot_meta_type      m_slotEraseFileMeta;
 };
