@@ -46,6 +46,8 @@ namespace torrent {
 HashTorrent::HashTorrent(ChunkList* c) :
   m_position(0),
   m_outstanding(-1),
+  m_errno(0),
+
   m_chunkList(c),
   m_queue(NULL) {
 }
@@ -73,6 +75,7 @@ void
 HashTorrent::clear() {
   m_outstanding = -1;
   m_position = 0;
+  m_errno = 0;
 }
 
 bool
@@ -133,33 +136,62 @@ HashTorrent::queue(bool quick) {
       m_position = itr->first;
     }
 
+    // Need to do increment later if we're going to support resume
+    // hashing a quick hashed torrent.
     ChunkHandle handle = m_chunkList->get(m_position++, false);
 
-    if (!handle.is_valid())
+    if (quick) {
+      // We're not actually interested in doing any hashing, so just
+      // skip what we know is not possible to hash.
+      //
+      // If the file does not exist then no valid error number is
+      // returned.
+
+      if (m_outstanding != 0)
+        throw internal_error("HashTorrent::queue() quick hashing but m_outstanding != 0.");
+
+      if (handle.is_valid())
+        return m_chunkList->release(&handle);
+      
+      if (handle.error_number().is_valid())
+        return;
+
       continue;
 
-    // We're not actually interested in doing any hashing, nor should
-    // be trigger any storage error.
-    if (quick)
-      return m_chunkList->release(&handle);
+    } else {
+      // If the error number is not valid, then we've just encountered a
+      // file that hasn't be created/resized. Which means we ignore it
+      // when doing initial hashing.
+      if (handle.error_number().is_valid()) {
+        if (handle.is_valid())
+          throw internal_error("HashTorrent::queue() error, but handle.is_valid().");
 
-    // If the error number is not valid, then we've just encountered a
-    // file that hasn't be created/resized. Which means we ignore it
-    // when doing initial hashing.
-    if (handle.error_number().is_valid()) {
-      // The rest of the outstanding chunks get ignored by
-      // DownloadWrapper::receive_hash_done.
-      clear();
+        // We wait for all the outstanding chunks to be checked before
+        // borking completely, else low-memory devices might not be able
+        // to finish the hash check.
+        if (m_outstanding != 0) {
+          m_position--;
+          return;
+        }
 
-      m_slotStorageError("Hash checker was unable to map chunk: " + std::string(handle.error_number().c_str()));
+        // The rest of the outstanding chunks get ignored by
+        // DownloadWrapper::receive_hash_done. Obsolete.
+        clear();
 
-      rak::priority_queue_erase(&taskScheduler, &m_delayChecked);
-      rak::priority_queue_insert(&taskScheduler, &m_delayChecked, cachedTime);
-      return;
+        m_errno = handle.error_number().value();
+
+        rak::priority_queue_erase(&taskScheduler, &m_delayChecked);
+        rak::priority_queue_insert(&taskScheduler, &m_delayChecked, cachedTime);
+        return;
+      }
+
+      // Missing file, skip the hash check.
+      if (!handle.is_valid())
+        continue;
+
+      m_slotCheckChunk(handle);
+      m_outstanding++;
     }
-    
-    m_slotCheckChunk(handle);
-    m_outstanding++;
   }
 
   if (m_outstanding == 0) {
