@@ -77,15 +77,47 @@ struct download_constructor_encoding_match :
 
 void
 DownloadConstructor::initialize(const Object& b) {
-  m_download->info()->set_name(b.get_key("info").get_key("name").as_string());
-
   if (b.has_key_string("encoding"))
-    m_defaultEncoding = b.get_key("encoding").as_string();
+    m_defaultEncoding = b.get_key_string("encoding");
 
+  parse_name(b.get_key("info"));
   parse_info(b.get_key("info"));
+
   parse_tracker(b);
 }
 
+// Currently using a hack of the path thingie to extract the correct
+// torrent name.
+void
+DownloadConstructor::parse_name(const Object& b) {
+  if (is_invalid_path_element(b.get_key("name")))
+    throw input_error("Bad torrent file, \"name\" is an invalid path name.");
+
+  std::list<Path> pathList;
+
+  pathList.push_back(Path());
+  pathList.back().set_encoding(m_defaultEncoding);
+  pathList.back().push_back(b.get_key_string("name"));
+
+  for (Object::map_type::const_iterator itr = b.as_map().begin();
+       (itr = std::find_if(itr, b.as_map().end(), download_constructor_is_single_path())) != b.as_map().end();
+       ++itr) {
+    pathList.push_back(Path());
+    pathList.back().set_encoding(itr->first.substr(sizeof("name.") - 1));
+    pathList.back().push_back(itr->second.as_string());
+  }
+
+  if (pathList.empty())
+    throw input_error("Bad torrent file, an entry has no valid name.");
+
+  Path name = choose_path(&pathList);
+
+  if (name.empty())
+    throw internal_error("DownloadConstructor::parse_name(...) Ended up with an empty Path.");
+
+  m_download->info()->set_name(name.front());
+}
+
 void
 DownloadConstructor::parse_info(const Object& b) {
   Content* c = m_download->main()->content();
@@ -98,7 +130,7 @@ DownloadConstructor::parse_info(const Object& b) {
 
   } else if (b.has_key("files")) {
     parse_multi_files(b.get_key("files"));
-    c->entry_list()->set_root_dir("./" + b.get_key("name").as_string());
+    c->entry_list()->set_root_dir("./" + b.get_key_string("name"));
 
   } else {
     throw input_error("Torrent must have either length or files entry");
@@ -107,13 +139,13 @@ DownloadConstructor::parse_info(const Object& b) {
   if (c->entry_list()->bytes_size() == 0)
     throw input_error("Torrent has zero length.");
 
-  if (b.get_key("piece length").as_value() <= (1 << 10) || b.get_key("piece length").as_value() > (128 << 20))
+  if (b.get_key_value("piece length") <= (1 << 10) || b.get_key_value("piece length") > (128 << 20))
     throw input_error("Torrent has an invalid \"piece length\".");
 
   // Set chunksize before adding files to make sure the index range is
   // correct.
-  c->set_complete_hash(b.get_key("pieces").as_string());
-  c->initialize(b.get_key("piece length").as_value());
+  c->set_complete_hash(b.get_key_string("pieces"));
+  c->initialize(b.get_key_value("piece length"));
 }
 
 void
@@ -121,7 +153,7 @@ DownloadConstructor::parse_tracker(const Object& b) {
   TrackerManager* tracker = m_download->main()->tracker_manager();
 
   if (b.has_key_list("announce-list"))
-    std::for_each(b.get_key("announce-list").as_list().begin(), b.get_key("announce-list").as_list().end(),
+    std::for_each(b.get_key_list("announce-list").begin(), b.get_key_list("announce-list").end(),
 		  rak::make_mem_fun(this, &DownloadConstructor::add_tracker_group));
 
   else if (b.has_key("announce"))
@@ -170,7 +202,7 @@ DownloadConstructor::parse_single_file(const Object& b) {
 
   pathList.push_back(Path());
   pathList.back().set_encoding(m_defaultEncoding);
-  pathList.back().push_back(b.get_key("name").as_string());
+  pathList.back().push_back(b.get_key_string("name"));
 
   for (Object::map_type::const_iterator itr = b.as_map().begin();
        (itr = std::find_if(itr, b.as_map().end(), download_constructor_is_single_path())) != b.as_map().end();
@@ -184,7 +216,7 @@ DownloadConstructor::parse_single_file(const Object& b) {
     throw input_error("Bad torrent file, an entry has no valid filename.");
 
   // Single file torrent
-  m_download->main()->content()->add_file(choose_path(&pathList), b.get_key("length").as_value());
+  m_download->main()->content()->add_file(choose_path(&pathList), b.get_key_value("length"));
 }
 
 void
@@ -195,15 +227,14 @@ DownloadConstructor::parse_multi_files(const Object& b) {
 
   m_download->main()->content()->entry_list()->reserve(b.as_list().size());
 
-  std::for_each(b.as_list().begin(), b.as_list().end(),
-		rak::make_mem_fun(this, &DownloadConstructor::add_file));
+  std::for_each(b.as_list().begin(), b.as_list().end(), rak::make_mem_fun(this, &DownloadConstructor::add_file));
 }
 
 void
 DownloadConstructor::add_file(const Object& b) {
   // Do a read first checking that we're above zero, then move to a
   // uint64_t.
-  int64_t length = b.get_key("length").as_value();
+  int64_t length = b.get_key_value("length");
 
   if (length < 0 || length > (int64_t)DownloadConstructor::max_file_length)
     throw input_error("Bad torrent file, invalid length for file given");
@@ -211,12 +242,11 @@ DownloadConstructor::add_file(const Object& b) {
   std::list<Path> pathList;
 
   if (b.has_key_list("path"))
-    pathList.push_back(create_path(b.get_key("path").as_list(), m_defaultEncoding));
+    pathList.push_back(create_path(b.get_key_list("path"), m_defaultEncoding));
 
   Object::map_type::const_iterator itr = b.as_map().begin();
   
-  while ((itr = std::find_if(itr, b.as_map().end(), download_constructor_is_multi_path()))
-	 != b.as_map().end()) {
+  while ((itr = std::find_if(itr, b.as_map().end(), download_constructor_is_multi_path())) != b.as_map().end()) {
     pathList.push_back(create_path(itr->second.as_list(), itr->first.substr(sizeof("path.") - 1)));
     ++itr;
   }
@@ -231,12 +261,10 @@ inline Path
 DownloadConstructor::create_path(const Object::list_type& plist, const std::string enc) {
   // Make sure we are given a proper file path.
   if (plist.empty())
-    throw input_error("Bad torrent file, \"path\" has zero entries");
+    throw input_error("Bad torrent file, \"path\" has zero entries.");
 
-  // Reneable.
-  if (std::find_if(plist.begin(), plist.end(),
-		   std::ptr_fun(&DownloadConstructor::is_invalid_path_element)) != plist.end())
-    throw input_error("Bad torrent file, \"path\" has zero entries or a zero lenght entry");
+  if (std::find_if(plist.begin(), plist.end(), std::ptr_fun(&DownloadConstructor::is_invalid_path_element)) != plist.end())
+    throw input_error("Bad torrent file, \"path\" has zero entries or a zero lenght entry.");
 
   Path p;
   p.set_encoding(enc);
@@ -254,8 +282,7 @@ DownloadConstructor::choose_path(std::list<Path>* pathList) {
   EncodingList::const_iterator encodingLast  = m_encodingList->end();
   
   for ( ; encodingFirst != encodingLast; ++encodingFirst) {
-    std::list<Path>::iterator itr = std::find_if(pathFirst, pathLast,
-						 rak::bind2nd(download_constructor_encoding_match(), encodingFirst->c_str()));
+    std::list<Path>::iterator itr = std::find_if(pathFirst, pathLast, rak::bind2nd(download_constructor_encoding_match(), encodingFirst->c_str()));
     
     if (itr != pathLast)
       pathList->splice(pathFirst, *pathList, itr);
