@@ -48,9 +48,9 @@ namespace torrent {
 DownloadManager::iterator
 DownloadManager::insert(DownloadWrapper* d) {
   if (find(d->info()->hash()) != end())
-    throw input_error("Could not add torrent as it already exists");
+    throw client_error("Could not add torrent as it already exists.");
 
-  return Base::insert(end(), d);
+  return base_type::insert(end(), d);
 }
 
 DownloadManager::iterator
@@ -60,18 +60,15 @@ DownloadManager::erase(DownloadWrapper* d) {
   if (itr == end())
     throw client_error("Tried to remove a torrent that doesn't exist");
     
-  (*itr)->main()->stop();
-  (*itr)->close();
-
   delete *itr;
-  return Base::erase(itr);
+  return base_type::erase(itr);
 }
 
 void
 DownloadManager::clear() {
   while (!empty()) {
-    delete Base::front();
-    Base::pop_front();
+    delete base_type::front();
+    base_type::pop_front();
   }
 }
 
@@ -90,7 +87,7 @@ DownloadManager::find_main(const std::string& hash) {
   iterator itr = std::find_if(begin(), end(), rak::equal(hash, rak::on(std::mem_fun(&DownloadWrapper::info), std::mem_fun(&DownloadInfo::hash))));
 
   // TODO: Move these checks somewhere else.
-  if (itr == end() || !(*itr)->main()->is_active())
+  if (itr == end() || !(*itr)->info()->is_active())
     return NULL;
   else
     return (*itr)->main();
