@@ -76,7 +76,7 @@ public:
   void                open();
   void                close();
 
-  bool                is_open() const                         { return m_main.is_open(); }
+//   bool                is_open() const                         { return m_main.is_open(); }
   bool                is_stopped() const;
 
   DownloadMain*       main()                                  { return &m_main; }
@@ -91,10 +91,6 @@ public:
   int                 connection_type() const                 { return m_connectionType; }
   void                set_connection_type(int t)              { m_connectionType = t; }
 
-  void                insert_available_list(const std::string& src);
-  void                extract_available_list(std::string& dest);
-
-  void                receive_keepalive();
   void                receive_initial_hash();
 
   void                check_chunk_hash(ChunkHandle handle);
@@ -107,7 +103,7 @@ public:
   void                receive_peer_connected(PeerConnectionBase* peer);
   void                receive_peer_disconnected(PeerConnectionBase* peer);
 
-  void                receive_tick();
+  void                receive_tick(uint32_t ticks);
 
   void                receive_update_priorities();
 
