@@ -39,12 +39,16 @@
 
 #include <unistd.h>
 
-namespace torrent {
+namespace rak {
+  class socket_address;
+}
 
-class SocketAddress;
+namespace torrent {
 
 class SocketFd {
 public:
+  typedef uint8_t priority_type;
+
   SocketFd() : m_fd(-1) {}
   explicit SocketFd(int fd) : m_fd(fd) {}
 
@@ -54,9 +58,13 @@ public:
   void                set_fd(int fd)                          { m_fd = fd; }
 
   bool                set_nonblock();
-  bool                set_throughput();
   bool                set_reuse_address(bool state);
 
+  bool                set_priority(priority_type p);
+
+  bool                set_send_buffer_size(uint32_t s);
+  bool                set_receive_buffer_size(uint32_t s);
+
   int                 get_error() const;
 
   bool                open_stream();
@@ -65,16 +73,18 @@ public:
 
   void                clear()                                 { m_fd = -1; }
 
-  bool                bind(const SocketAddress& sa);
-  bool                connect(const SocketAddress& sa);
+  bool                bind(const rak::socket_address& sa);
+  bool                connect(const rak::socket_address& sa);
 
   bool                listen(int size);
-  SocketFd            accept(SocketAddress* sa);
+  SocketFd            accept(rak::socket_address* sa);
 
 //   unsigned int        get_read_queue_size() const;
 //   unsigned int        get_write_queue_size() const;
 
 private:
+  inline void         check_valid() const;
+
   int                 m_fd;
 };
 
