@@ -47,18 +47,18 @@ class ThrottleNode;
 
 class ThrottleList : private std::list<ThrottleNode*> {
 public:
-  typedef std::list<ThrottleNode*> Base;
+  typedef std::list<ThrottleNode*> base_type;
 
-  using Base::iterator;
-  using Base::const_iterator;
-  using Base::reverse_iterator;
-  using Base::clear;
-  using Base::size;
+  using base_type::iterator;
+  using base_type::const_iterator;
+  using base_type::reverse_iterator;
+  using base_type::clear;
+  using base_type::size;
 
-  using Base::begin;
-  using Base::end;
-  using Base::rbegin;
-  using Base::rend;
+  using base_type::begin;
+  using base_type::end;
+  using base_type::rbegin;
+  using base_type::rend;
 
   ThrottleList();
 
