@@ -37,6 +37,7 @@
 #include "config.h"
 
 #include "data/content.h"
+#include "download/download_info.h"
 #include "download/download_main.h"
 #include "torrent/exceptions.h"
 #include "torrent/connection_manager.h"
@@ -79,15 +80,20 @@ Handshake::~Handshake() {
     throw internal_error("Handshake dtor called but m_fd is still open.");
 
   if (m_peerInfo != NULL) {
-    m_download->peer_list()->disconnected(m_peerInfo);
+    m_download->peer_list()->disconnected(m_peerInfo, 0);
+
+    m_peerInfo->unset_flags(PeerInfo::flag_handshake);
     m_peerInfo = NULL;
   }
 }
 
 void
-Handshake::initialize_outgoing(const rak::socket_address& sa, DownloadMain* d) {
+Handshake::initialize_outgoing(const rak::socket_address& sa, DownloadMain* d, PeerInfo* peerInfo) {
   m_download = d;
 
+  m_peerInfo = peerInfo;
+  m_peerInfo->set_flags(PeerInfo::flag_handshake);
+
   m_incoming = false;
   m_address = sa;
 
@@ -156,7 +162,7 @@ Handshake::event_read() {
         m_download = m_manager->download_info(std::string(m_readBuffer.position(), m_readBuffer.position() + 20));
         m_readBuffer.move_position(20);
 
-        if (m_download == NULL || !m_download->info()->accepting_new_peers())
+        if (m_download == NULL || !m_download->info()->is_accepting_new_peers())
           return m_manager->receive_failed(this);
 
         m_state = WRITE_FILL;
@@ -261,18 +267,22 @@ Handshake::prepare_peer_info() {
   if (std::memcmp(m_readBuffer.position(), m_download->info()->local_id().c_str(), 20) == 0)
     throw close_connection();
 
-  PeerList::iterator itr = m_download->peer_list()->connected(m_address);
+  // PeerInfo handling for outgoing connections needs to be moved to
+  // HandshakeManager.
+  if (m_peerInfo == NULL) {
+    if (!m_incoming)
+      throw internal_error("Handshake::prepare_peer_info() !m_incoming.");
 
-  if (itr == m_download->peer_list()->end())
-    throw close_connection();
+    m_peerInfo = m_download->peer_list()->connected(m_address.c_sockaddr(), PeerList::connect_incoming);
 
-  m_peerInfo = itr->second;
+    if (m_peerInfo == NULL)
+      throw close_connection();
 
+    m_peerInfo->set_flags(PeerInfo::flag_handshake);
+  }
+
+  std::memcpy(m_peerInfo->set_options(), m_options, 8);
   m_peerInfo->set_id(std::string(m_readBuffer.position(), m_readBuffer.position() + 20));
-  m_peerInfo->set_incoming(m_incoming);
-  //  m_peerInfo->set_socket_address(&m_address);
-
-  std::memcpy(m_peerInfo->get_options(), m_options, 8);
 }
 
 inline void
