@@ -42,8 +42,7 @@
 #include "net/protocol_buffer.h"
 #include "net/socket_stream.h"
 #include "torrent/bitfield.h"
-
-#include "peer_info.h"
+#include "torrent/peer_info.h"
 
 namespace torrent {
 
@@ -76,7 +75,7 @@ public:
 
   bool                is_active() const             { return m_state != INACTIVE; }
 
-  void                initialize_outgoing(const rak::socket_address& sa, DownloadMain* d);
+  void                initialize_outgoing(const rak::socket_address& sa, DownloadMain* d, PeerInfo* peerInfo);
   void                initialize_incoming(const rak::socket_address& sa);
   
   PeerInfo*           peer_info()                   { return m_peerInfo; }
