@@ -38,18 +38,18 @@
 
 #include <rak/socket_address.h>
 
-#include "torrent/connection_manager.h"
-#include "../manager.h"
-
 #include "torrent/exceptions.h"
 #include "download/download_info.h"
 #include "download/download_main.h"
+#include "torrent/connection_manager.h"
+#include "torrent/peer_info.h"
 
-#include "peer_info.h"
 #include "peer_connection_base.h"
 #include "handshake.h"
 #include "handshake_manager.h"
 
+#include "manager.h"
+
 namespace torrent {
 
 inline void
@@ -65,42 +65,42 @@ HandshakeManager::delete_handshake(Handshake* h) {
 
 HandshakeManager::size_type
 HandshakeManager::size_info(DownloadMain* info) const {
-  return std::count_if(Base::begin(), Base::end(), rak::equal(info, std::mem_fun(&Handshake::download)));
+  return std::count_if(base_type::begin(), base_type::end(), rak::equal(info, std::mem_fun(&Handshake::download)));
 }
 
 void
 HandshakeManager::clear() {
-  std::for_each(Base::begin(), Base::end(), std::bind1st(std::mem_fun(&HandshakeManager::delete_handshake), this));
-  Base::clear();
+  std::for_each(base_type::begin(), base_type::end(), std::bind1st(std::mem_fun(&HandshakeManager::delete_handshake), this));
+  base_type::clear();
 }
 
 void
 HandshakeManager::erase(Handshake* handshake) {
-  iterator itr = std::find(Base::begin(), Base::end(), handshake);
+  iterator itr = std::find(base_type::begin(), base_type::end(), handshake);
 
-  if (itr == Base::end())
+  if (itr == base_type::end())
     throw internal_error("HandshakeManager::erase(...) could not find handshake.");
 
-  Base::erase(itr);
+  base_type::erase(itr);
 }
 
 struct handshake_manager_equal : std::binary_function<const rak::socket_address*, const Handshake*, bool> {
   bool operator () (const rak::socket_address* sa1, const Handshake* p2) const {
-    return p2->peer_info() != NULL && *sa1 == *p2->peer_info()->socket_address();
+    return p2->peer_info() != NULL && *sa1 == *rak::socket_address::cast_from(p2->peer_info()->socket_address());
   }
 };
 
 bool
 HandshakeManager::find(const rak::socket_address& sa) {
-  return std::find_if(Base::begin(), Base::end(), std::bind1st(handshake_manager_equal(), &sa)) != Base::end();
+  return std::find_if(base_type::begin(), base_type::end(), std::bind1st(handshake_manager_equal(), &sa)) != base_type::end();
 }
 
 void
 HandshakeManager::erase_download(DownloadMain* info) {
-  iterator split = std::partition(Base::begin(), Base::end(), rak::not_equal(info, std::mem_fun(&Handshake::download)));
+  iterator split = std::partition(base_type::begin(), base_type::end(), rak::not_equal(info, std::mem_fun(&Handshake::download)));
 
-  std::for_each(split, Base::end(), std::bind1st(std::mem_fun(&HandshakeManager::delete_handshake), this));
-  Base::erase(split, Base::end());
+  std::for_each(split, base_type::end(), std::bind1st(std::mem_fun(&HandshakeManager::delete_handshake), this));
+  base_type::erase(split, base_type::end());
 }
 
 void
@@ -117,35 +117,41 @@ HandshakeManager::add_incoming(SocketFd fd, const rak::socket_address& sa) {
   Handshake* h = new Handshake(fd, this);
   h->initialize_incoming(sa);
 
-  Base::push_back(h);
+  base_type::push_back(h);
 }
   
 void
-HandshakeManager::add_outgoing(const rak::socket_address& sa, DownloadMain* info) {
+HandshakeManager::add_outgoing(const rak::socket_address& sa, DownloadMain* download) {
   if (!manager->connection_manager()->can_connect() ||
       !manager->connection_manager()->filter(sa.c_sockaddr()))
     return;
 
-  SocketFd fd;
+  PeerInfo* peerInfo = download->peer_list()->connected(sa.c_sockaddr(), PeerList::connect_keep_handshakes);
 
-  if (!fd.open_stream())
+  if (peerInfo == NULL)
     return;
 
+  SocketFd fd;
   const rak::socket_address* bindAddress = rak::socket_address::cast_from(manager->connection_manager()->bind_address());
 
-  if (!setup_socket(fd) ||
+  if (!fd.open_stream() ||
+      !setup_socket(fd) ||
       (bindAddress->is_bindable() && !fd.bind(*bindAddress)) ||
       !fd.connect(sa)) {
-    fd.close();
+
+    if (fd.is_valid())
+      fd.close();
+
+    download->peer_list()->disconnected(peerInfo, 0);
     return;
   }
 
   manager->connection_manager()->inc_socket_count();
 
   Handshake* h = new Handshake(fd, this);
-  h->initialize_outgoing(sa, info);
+  h->initialize_outgoing(sa, download, peerInfo);
 
-  Base::push_back(h);
+  base_type::push_back(h);
 }
 
 void
@@ -155,16 +161,17 @@ HandshakeManager::receive_succeeded(Handshake* h) {
 
   erase(h);
   h->clear();
+  h->peer_info()->unset_flags(PeerInfo::flag_handshake);
 
   PeerConnectionBase* pcb;
 
-  if (h->download()->is_active() &&
+  if (h->download()->info()->is_active() &&
 
       // We need to make libtorrent more selective in the clients it
       // connects to, and to move this somewhere else.
       (!h->download()->content()->is_done() || !h->bitfield()->is_all_set()) &&
 
-      (pcb = h->download()->connection_list()->insert(h->download(), h->peer_info(), h->get_fd(), h->bitfield())) != NULL) {
+      (pcb = h->download()->connection_list()->insert(h->peer_info(), h->get_fd(), h->bitfield())) != NULL) {
 
 //     h->download()->info()->signal_network_log().emit("Successful handshake: " + h->peer_info()->socket_address()->address_str());
     h->set_peer_info(NULL);
