@@ -46,14 +46,16 @@
 #include "download/choke_manager.h"
 #include "download/chunk_selector.h"
 #include "download/chunk_statistics.h"
+#include "download/download_info.h"
 #include "download/download_main.h"
 #include "net/socket_base.h"
-
 #include "torrent/connection_manager.h"
-#include "../manager.h"
+#include "torrent/peer_info.h"
 
 #include "peer_connection_base.h"
 
+#include "manager.h"
+
 namespace torrent {
 
 PeerConnectionBase::PeerConnectionBase() :
@@ -71,44 +73,8 @@ PeerConnectionBase::PeerConnectionBase() :
 }
 
 PeerConnectionBase::~PeerConnectionBase() {
-  if (!get_fd().is_valid())
-    return;
-
-  if (m_download == NULL)
-    throw internal_error("PeerConnection::~PeerConnection() m_fd is valid but m_state and/or m_net is NULL");
-
-  m_downloadQueue.clear();
-
-  up_chunk_release();
-  down_chunk_release();
-
-  m_download->choke_manager()->disconnected(this);
-  m_download->chunk_statistics()->received_disconnect(&m_peerChunks);
-
-  manager->poll()->remove_read(this);
-  manager->poll()->remove_write(this);
-  manager->poll()->remove_error(this);
-  manager->poll()->close(this);
-  
-  manager->connection_manager()->dec_socket_count();
-
-  get_fd().close();
-  get_fd().clear();
-
-  // Need to move more stuff into download*.
-  m_download->peer_list()->disconnected(m_peerInfo);
-  m_peerInfo = NULL;
-
-  m_download->upload_throttle()->erase(m_peerChunks.upload_throttle());
-  m_download->download_throttle()->erase(m_peerChunks.download_throttle());
-
-  m_up->set_state(ProtocolWrite::INTERNAL_ERROR);
-  m_down->set_state(ProtocolRead::INTERNAL_ERROR);
-
   delete m_up;
   delete m_down;
-
-  m_download = NULL;
 }
 
 void
@@ -152,16 +118,61 @@ PeerConnectionBase::initialize(DownloadMain* download, PeerInfo* peerInfo, Socke
 }
 
 void
-PeerConnectionBase::load_up_chunk() {
-  if (m_upChunk.is_valid() && m_upChunk.index() == m_upPiece.index())
+PeerConnectionBase::cleanup() {
+  if (!get_fd().is_valid())
     return;
 
+  if (m_download == NULL)
+    throw internal_error("PeerConnection::~PeerConnection() m_fd is valid but m_state and/or m_net is NULL");
+
+  m_downloadQueue.clear();
+
+  up_chunk_release();
+  down_chunk_release();
+
+  m_download->choke_manager()->disconnected(this);
+  m_download->chunk_statistics()->received_disconnect(&m_peerChunks);
+
+  manager->poll()->remove_read(this);
+  manager->poll()->remove_write(this);
+  manager->poll()->remove_error(this);
+  manager->poll()->close(this);
+  
+  manager->connection_manager()->dec_socket_count();
+
+  get_fd().close();
+  get_fd().clear();
+
+  m_download->upload_throttle()->erase(m_peerChunks.upload_throttle());
+  m_download->download_throttle()->erase(m_peerChunks.download_throttle());
+
+  m_up->set_state(ProtocolWrite::INTERNAL_ERROR);
+  m_down->set_state(ProtocolRead::INTERNAL_ERROR);
+
+  m_download = NULL;
+}
+
+void
+PeerConnectionBase::load_up_chunk() {
+  if (m_upChunk.is_valid() && m_upChunk.index() == m_upPiece.index()) {
+    // Better checking needed.
+    //     m_upChunk.chunk()->preload(m_upPiece.offset(), m_upChunk.chunk()->size());
+    return;
+  }
+
   up_chunk_release();
   
   m_upChunk = m_download->chunk_list()->get(m_upPiece.index(), false);
   
   if (!m_upChunk.is_valid())
     throw storage_error("File chunk read error: " + std::string(m_upChunk.error_number().c_str()));
+
+  // Make sure we preload the next step once we get past the length
+  // here. This is just some testing, don't include this with the
+  // release. (Yet)
+//   if (m_peerChunks.upload_throttle()->rate()->rate() >= 10 << 10)
+//     m_upChunk.chunk()->preload(m_upPiece.offset(), m_upChunk.chunk()->size());
+//   m_upChunk.chunk()->preload(m_upPiece.offset(), std::min(128u << 10, m_peerChunks.upload_throttle()->rate()->rate() * 10));
 }
 
 void
@@ -206,7 +217,7 @@ PeerConnectionBase::receive_throttle_up_activate() {
 
 void
 PeerConnectionBase::event_error() {
-  m_download->connection_list()->erase(this);
+  m_download->connection_list()->erase(this, 0);
 }
 
 bool
@@ -300,8 +311,8 @@ bool
 PeerConnectionBase::down_chunk_from_buffer() {
   m_down->buffer()->move_position(down_chunk_process(m_down->buffer()->position(), m_down->buffer()->remaining()));
 
-  if (m_downloadQueue.transfer()->is_finished() && m_down->buffer()->remaining() != 0)
-    throw internal_error("PeerConnectionBase::down_chunk_from_buffer() transfer->is_finished() && m_down->buffer()->remaining() != 0.");
+  if (!m_downloadQueue.transfer()->is_finished() && m_down->buffer()->remaining() != 0)
+    throw internal_error("PeerConnectionBase::down_chunk_from_buffer() !transfer->is_finished() && m_down->buffer()->remaining() != 0.");
 
   return m_downloadQueue.transfer()->is_finished();
 }  
@@ -518,7 +529,7 @@ PeerConnectionBase::should_request() {
     // || m_down->get_state() == ProtocolRead::READ_SKIP_PIECE)
     return false;
 
-  else if (!m_download->get_endgame())
+  else if (!m_download->delegator()->get_aggressive())
     return true;
 
   else
