@@ -37,18 +37,16 @@
 #ifndef LIBTORRENT_PROTOCOL_PEER_CONNECTION_BASE_H
 #define LIBTORRENT_PROTOCOL_PEER_CONNECTION_BASE_H
 
-#include "data/chunk.h"
 #include "data/chunk_handle.h"
 #include "net/socket_stream.h"
-#include "globals.h"
-#include "torrent/connection_manager.h"
 #include "torrent/poll.h"
 
-#include "peer_info.h"
 #include "peer_chunks.h"
 #include "protocol_base.h"
 #include "request_list.h"
 
+#include "globals.h"
+
 #include "manager.h"
 
 namespace torrent {
@@ -74,6 +72,7 @@ public:
   virtual ~PeerConnectionBase();
   
   void                initialize(DownloadMain* download, PeerInfo* p, SocketFd fd, Bitfield* bitfield);
+  void                cleanup();
 
   bool                is_up_choked()                { return m_up->choked(); }
   bool                is_up_interested()            { return m_up->interested(); }
@@ -84,7 +83,8 @@ public:
 
   bool                is_seeder() const             { return m_peerChunks.is_seeder(); }
 
-  const PeerInfo*     peer_info() const             { return m_peerInfo; }
+  PeerInfo*           peer_info()                   { return m_peerInfo; }
+  const PeerInfo*     c_peer_info() const           { return m_peerInfo; }
   PeerChunks*         peer_chunks()                 { return &m_peerChunks; }
 
   RequestList*        download_queue()              { return &m_downloadQueue; }
@@ -111,8 +111,6 @@ public:
   void                push_unread(const void* data, uint32_t size);
 
 protected:
-  typedef Chunk::iterator ChunkPart;
-
   inline bool         read_remaining();
   inline bool         write_remaining();
 
