@@ -43,6 +43,7 @@
 #include "data/chunk_list_node.h"
 #include "download/chunk_selector.h"
 #include "download/chunk_statistics.h"
+#include "download/download_info.h"
 #include "download/download_main.h"
 
 #include "peer_connection_leech.h"
@@ -345,20 +346,20 @@ PeerConnectionLeech::event_read() {
   // Exception handlers:
 
   } catch (close_connection& e) {
-    m_download->connection_list()->erase(this);
+    m_download->connection_list()->erase(this, 0);
 
   } catch (blocked_connection& e) {
     m_download->info()->signal_network_log().emit("Momentarily blocked read connection.");
-    m_download->connection_list()->erase(this);
+    m_download->connection_list()->erase(this, 0);
 
   } catch (network_error& e) {
     m_download->info()->signal_network_log().emit(e.what());
 
-    m_download->connection_list()->erase(this);
+    m_download->connection_list()->erase(this, 0);
 
   } catch (storage_error& e) {
     m_download->info()->signal_storage_error().emit(e.what());
-    m_download->connection_list()->erase(this);
+    m_download->connection_list()->erase(this, 0);
 
   } catch (base_error& e) {
     std::stringstream s;
@@ -476,19 +477,19 @@ PeerConnectionLeech::event_write() {
     } while (true);
 
   } catch (close_connection& e) {
-    m_download->connection_list()->erase(this);
+    m_download->connection_list()->erase(this, 0);
 
   } catch (blocked_connection& e) {
     m_download->info()->signal_network_log().emit("Momentarily blocked write connection.");
-    m_download->connection_list()->erase(this);
+    m_download->connection_list()->erase(this, 0);
 
   } catch (network_error& e) {
     m_download->info()->signal_network_log().emit(e.what());
-    m_download->connection_list()->erase(this);
+    m_download->connection_list()->erase(this, 0);
 
   } catch (storage_error& e) {
     m_download->info()->signal_storage_error().emit(e.what());
-    m_download->connection_list()->erase(this);
+    m_download->connection_list()->erase(this, 0);
 
   } catch (base_error& e) {
     std::stringstream s;
