@@ -38,15 +38,16 @@
 #define LIBTORRENT_PRIORITY_H
 
 #include <inttypes.h>
-#include <rak/ranges.h>
 
 namespace torrent {
 
-typedef enum {
+enum priority_enum {
   PRIORITY_OFF = 0,
   PRIORITY_NORMAL,
   PRIORITY_HIGH
-} priority_t;
+};
+
+typedef priority_enum priority_t;
 
 }
 
