@@ -56,6 +56,7 @@ class FileList;
 class Rate;
 class Object;
 class Peer;
+class PeerList;
 class TrackerList;
 class TransferList;
 
@@ -73,7 +74,7 @@ public:
   void                close();
 
   // When 'tryQuick' is true, it will only check if the chunks can be
-  // mmaped and returns if one is encountered. If it doesn't find any
+  // mmaped and stops if one is encountered. If it doesn't find any
   // mappable chunks it will return true to indicate that it is
   // finished and a hash done signal has been queued.
   //
@@ -108,6 +109,8 @@ public:
   FileList            file_list() const;
   TrackerList         tracker_list() const;
 
+  PeerList*           peer_list();
+  const PeerList*     peer_list() const;
   const TransferList* transfer_list() const;
 
   Rate*               down_rate();
@@ -121,6 +124,8 @@ public:
   // Size of the torrent.
   uint64_t            bytes_total() const;
 
+  uint64_t            free_diskspace() const;
+
   uint32_t            chunks_size() const;
   uint32_t            chunks_done() const;
   uint32_t            chunks_total() const;
@@ -136,6 +141,7 @@ public:
   // use an cleared bitfield and check the whole range.
   //
   // These must be called when is_open, !is_checked and !is_checking.
+  void                set_bitfield(bool allSet);
   void                set_bitfield(uint8_t* first, uint8_t* last);
   void                clear_range(uint32_t first, uint32_t last);
 
@@ -145,23 +151,6 @@ public:
   // saved.
   void                sync_chunks();
 
-  // Temporary hack until i can move the available list stuf somewhere
-  // and make a nice interface for it.
-
-  void                insert_addresses(const std::string& addresses);
-  void                extract_addresses(std::string& addresses);
-
-  // This should also be moved out into a seperate class, possibly
-  // global settings.
-  uint32_t            timeout_sync() const;
-  void                set_timeout_sync(uint32_t seconds);
-
-  uint32_t            timeout_safe_sync() const;
-  void                set_timeout_safe_sync(uint32_t seconds);
-
-  uint32_t            max_chunks_queued() const;
-  void                set_max_chunks_queued(uint32_t chunks);
-
   uint32_t            peers_min() const;
   uint32_t            peers_max() const;
   uint32_t            peers_connected() const;
