@@ -125,6 +125,11 @@ void
 perform() {
   cachedTime = rak::timer::current();
 
+  // Ensure we don't call rak::timer::current() twice if there was no
+  // scheduled tasks called.
+  if (taskScheduler.empty() || taskScheduler.top()->time() > cachedTime)
+    return;
+
   while (!taskScheduler.empty() && taskScheduler.top()->time() <= cachedTime) {
     rak::priority_item* v = taskScheduler.top();
     taskScheduler.pop();
@@ -132,16 +137,24 @@ perform() {
     v->clear_time();
     v->call();
   }
+
+  // Update the timer again to ensure we get accurate triggering of
+  // msec timers.
+  cachedTime = rak::timer::current();
 }
 
 bool
 is_inactive() {
   return manager == NULL ||
-    std::find_if(manager->download_manager()->begin(), manager->download_manager()->end(),
-		      std::not1(std::mem_fun(&DownloadWrapper::is_stopped)))
+    std::find_if(manager->download_manager()->begin(), manager->download_manager()->end(), std::not1(std::mem_fun(&DownloadWrapper::is_stopped)))
     == manager->download_manager()->end();
 }
 
+ChunkManager*
+chunk_manager() {
+  return manager->chunk_manager();
+}
+
 ConnectionManager*
 connection_manager() {
   return manager->connection_manager();
@@ -311,8 +324,12 @@ download_add(Object* object) {
 
   ctor.initialize(*object);
 
-  download->initialize(object_sha1(&object->get_key("info")),
-		       PEER_NAME + rak::generate_random<std::string>(20 - std::string(PEER_NAME).size()));
+  std::string infoHash = object_sha1(&object->get_key("info"));
+
+  if (manager->download_manager()->find(infoHash) != manager->download_manager()->end())
+    throw input_error("Info hash already used by another torrent.");
+
+  download->initialize(infoHash, PEER_NAME + rak::generate_random<std::string>(20 - std::string(PEER_NAME).size()));
 
   // Default PeerConnection factory functions.
   download->main()->connection_list()->slot_new_connection(&createPeerConnectionDefault);
