@@ -1,5 +1,5 @@
 // libTorrent - BitTorrent library
-// Copyright (C) 2005, Jari Sundell
+// Copyright (C) 2005-2006, Jari Sundell
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -37,7 +37,8 @@
 #ifndef LIBTORRENT_TRACKER_H
 #define LIBTORRENT_TRACKER_H
 
-#include <torrent/common.h>
+#include <string>
+#include <inttypes.h>
 
 namespace torrent {
 
@@ -71,6 +72,11 @@ public:
   const std::string&  tracker_id() const;
   Type                tracker_type() const;
 
+  uint64_t            scrape_time_last() const;
+  uint32_t            scrape_complete() const;
+  uint32_t            scrape_incomplete() const;
+  uint32_t            scrape_downloaded() const;
+
 private:
   value_type          m_tracker;
 };
